@@ -7,8 +7,8 @@ if False:  # MYPY
 
 _package_data = dict(
     full_package_name='ruamel.yaml',
-    version_info=(0, 15, 19),
-    __version__='0.15.19',
+    version_info=(0, 15, 20),
+    __version__='0.15.20',
     author='Anthon van der Neut',
     author_email='a.van.der.neut@ruamel.eu',
     description='ruamel.yaml is a YAML parser/emitter that supports roundtrip preservation of comments, seq/map flow style, and map key order',  # NOQA
@@ -18,6 +18,7 @@ _package_data = dict(
         ':platform_python_implementation=="CPython" and python_version<="2.7"':
         ['ruamel.ordereddict'],
         'jinja2': ['ruamel.yaml.jinja2>=0.2'],
+        'docs': ['ryd'],
     },
     ext_modules=[dict(
         name='_ruamel_yaml',
@@ -26,7 +27,7 @@ _package_data = dict(
                  'ext/emitter.c',
             ],
             lib=[],
-            test='#include "ext/yaml.h"\n\nint main(int argc, char* argv[])\n{\nyaml_parser_t parser;\nparser = parser;  /* prevent warning */\nreturn 0;\n}\n',  # NOQA
+            # test='#include "ext/yaml.h"\n\nint main(int argc, char* argv[])\n{\nyaml_parser_t parser;\nparser = parser;  /* prevent warning */\nreturn 0;\n}\n',  # NOQA
         )],
     classifiers=[
         'Programming Language :: Python :: 2.7',
